@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/bin/sh
 
 echo "zfs-generator: starting" >> /dev/kmsg
 
@@ -11,7 +11,7 @@ GENERATOR_DIR="$1"
 [ -f /lib/dracut-lib.sh ] && dracutlib=/lib/dracut-lib.sh
 [ -f /usr/lib/dracut/modules.d/99base/dracut-lib.sh ] && dracutlib=/usr/lib/dracut/modules.d/99base/dracut-lib.sh
 
-type getarg >/dev/null 2>&1 || {
+command -v getarg >/dev/null 2>&1 || {
     echo "zfs-generator: loading Dracut library from $dracutlib" >> /dev/kmsg
     . "$dracutlib"
 }
@@ -22,16 +22,17 @@ type getarg >/dev/null 2>&1 || {
 
 # If root is not ZFS= or zfs: or rootfstype is not zfs
 # then we are not supposed to handle it.
-[ "${root##zfs:}" = "${root}" -a "${root##ZFS=}" = "${root}" -a "$rootfstype" != "zfs" ] && exit 0
+[ "${root##zfs:}" = "${root}" ] &&
+	[ "${root##ZFS=}" = "${root}" ] &&
+	[ "$rootfstype" != "zfs" ] &&
+	exit 0
 
 rootfstype=zfs
-if echo "${rootflags}" | grep -Eq '^zfsutil$|^zfsutil,|,zfsutil$|,zfsutil,' ; then
-    true
-elif test -n "${rootflags}" ; then
-    rootflags="zfsutil,${rootflags}"
-else
-    rootflags=zfsutil
-fi
+case ",${rootflags}," in
+	*,zfsutil,*) ;;
+	,,)	rootflags=zfsutil ;;
+	*)	rootflags="zfsutil,${rootflags}" ;;
+esac
 
 echo "zfs-generator: writing extension for sysroot.mount to $GENERATOR_DIR"/sysroot.mount.d/zfs-enhancement.conf >> /dev/kmsg
 
@@ -41,8 +42,7 @@ echo "zfs-generator: writing extension for sysroot.mount to $GENERATOR_DIR"/sysr
 {
     echo "[Unit]"
     echo "Before=initrd-root-fs.target"
-    echo "After=zfs-import-scan.service"
-    echo "After=zfs-import-cache.service"
+    echo "After=zfs-import.target"
     echo "[Mount]"
     if [ "${root}" = "zfs:AUTO" ] ; then
       echo "PassEnvironment=BOOTFS"
